@@ -12,7 +12,7 @@ use List::Util qw( reduce );
 
 use System::Command::Reaper;
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 # a few simple accessors
 for my $attr (qw( pid stdin stdout stderr exit signal core options )) {
@@ -93,6 +93,11 @@ sub new {
     return $self;
 }
 
+sub spawn {
+    my ( $class, @cmd ) = @_;
+    return @{ System::Command->new(@cmd) }{qw( pid stdin stdout stderr )};
+}
+
 
 # delegate close() to the reaper
 sub close { $_[0]{reaper}->reap() }
@@ -129,6 +134,9 @@ System::Command - Object for running system commands
     $cmd->signal();    # signal
     $cmd->core();      # core dumped? (boolean)
 
+    # cut to the chase
+    my ( $pid, $in, $out, $err ) = System::Command->spawn(@cmd);
+
 =head1 DESCRIPTION
 
 C<System::Command> is a class that launches external system commands
@@ -187,6 +195,13 @@ Close all pipes to the child process, collects exit status, etc.
 and defines a number of attributes (see below).
 
 
+=head2 spawn( @cmd )
+
+This shortcut method calls C<new()> (and so accepts options in the same
+manner) and directly returns the C<pid>, C<stdin>, C<stdout> and C<stderr>
+attributes, in that order.
+
+
 =head2 Accessors
 
 The attributes of a C<System::Command> object are also accessible
